#
# spec file for package kunifiedpush
#
# Copyright (c) 2025 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%bcond_without released

%define kf6_version 6.6.0
%define qt6_version 6.5.0
#
Name:           kunifiedpush
Version:        25.04.3
Release:        1.1
Summary:        UnifiedPush client components
License:        LGPL-2.0-or-later
URL:            https://www.kde.org/
Source:         https://download.kde.org/stable/kunifiedpush/%{name}-%{version}.tar.xz
%if %{with released}
Source1:        https://download.kde.org/stable/kunifiedpush/%{name}-%{version}.tar.xz.sig
Source2:        applications.keyring
%endif
# For %%check
BuildRequires:  dbus-1
BuildRequires:  kf6-extra-cmake-modules >= %{kf6_version}
BuildRequires:  cmake(KF6CoreAddons) >= %{kf6_version}
BuildRequires:  cmake(KF6I18n) >= %{kf6_version}
BuildRequires:  cmake(KF6KCMUtils) >= %{kf6_version}
BuildRequires:  cmake(KF6Service) >= %{kf6_version}
BuildRequires:  cmake(Qt6Core) >= %{qt6_version}
BuildRequires:  cmake(Qt6DBus) >= %{qt6_version}
BuildRequires:  cmake(Qt6Test) >= %{qt6_version}
BuildRequires:  cmake(Qt6WebSockets) >= %{qt6_version}
# The KCM is slightly useless without the library
Requires:       libKUnifiedPush1
Requires:       systemsettings6

%description
KUnifiedPush provides push notifications for KDE applications. Push
notifications are a mechanism to support applications that occasionally need to
receive some kind of information from their server-side part, and where
receiving in a timely manner matters.

Three possible provider backends are provided:
- Ntfy
- Nextpush
- Gotify

%package -n libKUnifiedPush1
Summary:        KUnifiedPush library
Recommends:     kunifiedpush

%description -n libKUnifiedPush1
KUnifiedPush provides push notifications for KDE applications. Push
notifications are a mechanism to support applications that occasionally need to
receive some kind of information from their server-side part, and where
receiving in a timely manner matters.

%package devel
Summary:        Development files for KUnifiedPush
Requires:       libKUnifiedPush1 = %{version}

%description devel
Development files for using KUnifiedPush in your applications.

%lang_package

%prep
%autosetup -p1

%build
%cmake_kf6 -DBUILD_TESTING:BOOL=TRUE

%kf6_build

%install
%kf6_install

%find_lang %{name} --all-name

%ldconfig_scriptlets -n libKUnifiedPush1

%check
pushd %{__kf6_builddir}
# The connectortest test passes locally but fails when running in a KVM
dbus-run-session /usr/bin/ctest --output-on-failure --exclude-regex "connectortest"
popd

%files
%license LICENSES/*
%doc README.md
%dir %{_kf6_configdir}/KDE
%config %{_kf6_configdir}/KDE/kunifiedpush-distributor.conf
%{_kf6_applicationsdir}/kcm_push_notifications.desktop
%{_kf6_bindir}/kunifiedpush-distributor
%{_kf6_configdir}/autostart/org.kde.kunifiedpush-distributor.desktop
%{_kf6_debugdir}/org_kde_kunifiedpush.categories
%{_kf6_plugindir}/plasma/kcms/systemsettings/kcm_push_notifications.so

%files -n libKUnifiedPush1
%license LICENSES/*
%{_kf6_libdir}/libKUnifiedPush.so.*

%files devel
%{_includedir}/KUnifiedPush/
%{_kf6_cmakedir}/KUnifiedPush/
%{_kf6_libdir}/libKUnifiedPush.so

%files lang -f %{name}.lang

%changelog
* Tue Jul  1 2025 Christophe Marin <christophe@krop.fr>
- Update to 25.04.3
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/gear/25.04.3/
- Changes since 25.04.2:
  * Force ntfy to consider message as UnifiedPush messages
* Tue Jun  3 2025 Christophe Marin <christophe@krop.fr>
- Update to 25.04.2
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/gear/25.04.2/
- No code change since 25.04.1
* Wed May  7 2025 Christophe Marin <christophe@krop.fr>
- Update to 25.04.1
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/gear/25.04.1/
- No code change since 25.04.0
* Mon Apr 14 2025 Christophe Marin <christophe@krop.fr>
- Update to 25.04.0
  * New feature release
  * For more details please see:
  * https://kde.org/announcements/gear/25.04.0/
- No code change since 25.03.90
* Sat Mar 29 2025 Christophe Marin <christophe@krop.fr>
- Update to 25.03.90
  * New feature release
- Changes since 24.12.3:
  * Register the MessageReciever in the AndroidManifest.xml again
  * Allow querying the available UnifiedPush distributors on Android
  * Add a better description to the KCM
  * Show headers in qtc6
  * Qt6WebSockets is not required with KUNIFIEDPUSH_CLIENT_ONLY
* Tue Mar  4 2025 Christophe Marin <christophe@krop.fr>
- Update to 24.12.3
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/gear/24.12.3/
- No code change since 24.12.2
* Tue Feb  4 2025 Christophe Marin <christophe@krop.fr>
- Update to 24.12.2
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/gear/24.12.2/
- No code change since 24.12.1
* Tue Jan  7 2025 Christophe Marin <christophe@krop.fr>
- Update to 24.12.1
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/gear/24.12.1/
- No code change since 24.12.0
* Sun Dec  8 2024 Christophe Marin <christophe@krop.fr>
- Update to 24.12.0
  * New feature release
  * For more details please see:
  * https://kde.org/announcements/gear/24.12.0/
- Changes since 24.11.90:
  * Qt6WebSockets is not required with KUNIFIEDPUSH_CLIENT_ONLY
* Mon Dec  2 2024 Christophe Marin <christophe@krop.fr>
- Update to 24.11.90
  * New feature release
- No code change since 24.11.80
* Sat Nov 16 2024 Christophe Marin <christophe@krop.fr>
- Update to 24.11.80
  * New feature release
- Changes since 1.0.0:
  * Don't include quiet packages in feature_summary
  * Const'ify pointer
  * Remove unused include
  * Remove qt5 support
* Thu Oct 24 2024 Christophe Marin <christophe@krop.fr>
- Add kunifiedpush
  https://blogs.kde.org/2024/10/19/kunifiedpush-1.0.0-is-out/
